@@ -5,7 +5,7 @@ Single hash table trie
 from typing import Any, Tuple, Dict
 
 
-TabKey = Tuple[int, int, Any]
+TabKey = str
 TabVal = Tuple[int, bool, Any]
 Trie = Dict[TabKey, TabVal]
 Member = Any
@@ -19,6 +19,11 @@ def _first(i: MemberWithPayload) -> Member:
     return i[0]
 
 
+def create_key(row_no: int, offset: int, member: Any) -> str:
+    """Create a key"""
+    return f'{row_no}:{offset}:{member}'
+
+
 def list_to_trie(members_with_payload: list[MemberWithPayload]) -> Trie:
     """Construct a trie from sorted members with payload."""
     trie: Trie = {}
@@ -30,7 +35,7 @@ def list_to_trie(members_with_payload: list[MemberWithPayload]) -> Trie:
         for j, member in enumerate(members):
             is_terminal = len(members) == j + 1
             member = members[j]
-            key: TabKey = (row_no, j, member)
+            key: TabKey = create_key(row_no, j, member)
             if key in trie:
                 row_no = trie[key][0]
             else:
@@ -45,7 +50,7 @@ def lookup(trie: Trie,
            offset: int,
            member_part: Any) -> None | TabVal:
     """Lookup is done by searching an element of members in the tree."""
-    key = (i, offset, member_part)
+    key = create_key(i, offset, member_part)
     if key not in trie:
         return None
     return trie[key]
